==> qtjambi-xml-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiXml/QDomText_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomText(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomText")
    QDomText *_ptr = reinterpret_cast<QDomText *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomText()
void __qt_construct_QDomText_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomText()")
    Q_UNUSED(__java_arguments)
    QDomText *__qt_this = new(__qtjambi_ptr) QDomText();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDomText(QDomText)
void __qt_construct_QDomText_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomText(QDomText)")
    jobject x0 = __java_arguments[0].l;
    const QDomText& __qt_x0 = qtjambi_cast<const QDomText& >(__jni_env, x0);
    QDomText *__qt_this = new(__qtjambi_ptr) QDomText(__qt_x0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDomText
void __qt_destruct_QDomText(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomText")
    reinterpret_cast<QDomText*>(ptr)->~QDomText();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomText::QDomText()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_initialize_1native__Lio_qt_xml_QDomText_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomText::QDomText()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomText_0, sizeof(QDomText), typeid(QDomText), false, &deleter_QDomText, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomText::QDomText(QDomText)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_initialize_1native__Lio_qt_xml_QDomText_2Lio_qt_xml_QDomText_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomText::QDomText(QDomText)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomText_1, sizeof(QDomText), typeid(QDomText), false, &deleter_QDomText, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomText::operator=(QDomText)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_assign_1native_1cref_1QDomText__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomText *__qt_this = QtJambiAPI::objectFromNativeId<QDomText>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomText::operator=(QDomText)", __qt_this)
        const QDomText& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomText>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomText::splitText(int)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_splitText_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QDomText *__qt_this = QtJambiAPI::objectFromNativeId<QDomText>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomText::splitText(int)", __qt_this)
        QDomText __qt_return_value = __qt_this->splitText(static_cast<int>(offset0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomText *__qt_this = QtJambiAPI::objectFromNativeId<QDomText>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomText(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomText>("QDomText", "io/qt/xml/QDomText");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomText, {
        ConstructorInfo(&__qt_construct_QDomText_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomText_1, "Lio/qt/xml/QDomText;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomText);
    registerMetaType<QDomText>("QDomText");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.7.1.jar: sources/QtJambiXml/QDomText_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomText(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomText")
    QDomText *_ptr = reinterpret_cast<QDomText *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomText()
void __qt_construct_QDomText(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomText()")
    Q_UNUSED(__java_arguments)
    QDomText *__qt_this = new(__qtjambi_ptr) QDomText();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomText::QDomText()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_initialize_1native__Lio_qt_xml_QDomText_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomText::QDomText()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomText, sizeof(QDomText), typeid(QDomText), 0, false, &deleter_QDomText, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomText(QDomText)
void __qt_construct_QDomText_cref_QDomText(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomText(QDomText)")
    jobject x0 = __java_arguments[0].l;
    const QDomText& __qt_x0 = qtjambi_cast<const QDomText&>(__jni_env, x0);
    QDomText *__qt_this = new(__qtjambi_ptr) QDomText(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomText::QDomText(QDomText)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_initialize_1native__Lio_qt_xml_QDomText_2Lio_qt_xml_QDomText_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomText::QDomText(QDomText)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomText_cref_QDomText, sizeof(QDomText), typeid(QDomText), 0, false, &deleter_QDomText, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomText
void __qt_destruct_QDomText(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomText")
    reinterpret_cast<QDomText*>(ptr)->~QDomText();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomText::operator=(QDomText)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_assign_1native_1cref_1QDomText__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomText *__qt_this = QtJambiAPI::objectFromNativeId<QDomText>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomText::operator=(QDomText)", __this_nativeId)
        const QDomText& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomText>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomText::splitText(int)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_splitText_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QDomText *__qt_this = QtJambiAPI::objectFromNativeId<QDomText>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomText::splitText(int)", __this_nativeId)
        QDomText __qt_return_value = __qt_this->splitText(static_cast<int>(offset0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomText_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomText *__qt_this = QtJambiAPI::objectFromNativeId<QDomText>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomText(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomText>("QDomText", "io/qt/xml/QDomText");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomText, {
        ConstructorInfo(&__qt_construct_QDomText, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomText_cref_QDomText, "Lio/qt/xml/QDomText;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomText);
    registerMetaType<QDomText>("QDomText");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
